==> mariadb-java-client-2.5.2-sources.jar: org/mariadb/jdbc/internal/failover/Listener.java <==
/*
 *
 * MariaDB Client for Java
 *
 * Copyright (c) 2012-2014 Monty Program Ab.
 * Copyright (c) 2015-2019 MariaDB Ab.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 * This particular MariaDB Client for Java file is work
 * derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 * the following copyright and notice provisions:
 *
 * Copyright (c) 2009-2011, Marcus Eriksson
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name of the driver nor the names of its contributors may not be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 */

package org.mariadb.jdbc.internal.failover;

import org.mariadb.jdbc.*;
import org.mariadb.jdbc.internal.failover.tools.*;
import org.mariadb.jdbc.internal.protocol.*;
import org.mariadb.jdbc.internal.util.dao.*;

import java.lang.reflect.*;
import java.net.*;
import java.sql.*;
import java.util.*;

public interface Listener {

  FailoverProxy getProxy();

  void setProxy(FailoverProxy proxy);

  void initializeConnection() throws SQLException;

  void preExecute() throws SQLException;

  void preClose();

  void preAbort();

  long getServerThreadId();

  void reconnectFailedConnection(SearchFilter filter) throws SQLException;

  void switchReadOnlyConnection(Boolean readonly) throws SQLException;

  HandleErrorResult primaryFail(Method method, Object[] args, boolean killCmd, boolean wasClosed)
      throws SQLException;

  Object invoke(Method method, Object[] args, Protocol specificProtocol) throws Throwable;

  Object invoke(Method method, Object[] args) throws Throwable;

  HandleErrorResult handleFailover(
      SQLException qe, Method method, Object[] args, Protocol protocol, boolean wasClosed)
      throws Throwable;

  void foundActiveMaster(Protocol protocol) throws SQLException;

  Set<HostAddress> getBlacklistKeys();

  void addToBlacklist(HostAddress hostAddress);

  void removeFromBlacklist(HostAddress hostAddress);

  void syncConnection(Protocol from, Protocol to) throws SQLException;

  UrlParser getUrlParser();

  void throwFailoverMessage(
      HostAddress failHostAddress,
      boolean wasMaster,
      SQLException queryException,
      boolean reconnected)
      throws SQLException;

  boolean isAutoReconnect();

  int getRetriesAllDown();

  boolean isExplicitClosed();

  void reconnect() throws SQLException;

  boolean isReadOnly();

  boolean inTransaction();

  int getMajorServerVersion();

  boolean isMasterConnection();

  boolean isClosed();

  boolean versionGreaterOrEqual(int major, int minor, int patch);

  boolean isServerMariaDb();

  boolean sessionStateAware();

  boolean noBackslashEscapes();

  boolean isValid(int timeout) throws SQLException;

  void prolog(long maxRows, MariaDbConnection connection, MariaDbStatement statement)
      throws SQLException;

  String getCatalog() throws SQLException;

  int getTimeout() throws SocketException;

  Protocol getCurrentProtocol();

  boolean hasHostFail();

  boolean canRetryFailLoop();

  SearchFilter getFilterForFailedHost();

  boolean isMasterConnected();

  boolean setMasterHostFail();

  boolean isMasterHostFail();

  long getLastQueryNanos();

  boolean checkMasterStatus(SearchFilter searchFilter);

  void rePrepareOnSlave(ServerPrepareResult oldServerPrepareResult, boolean mustExecuteOnMaster)
      throws SQLException;

  void reset() throws SQLException;
}

==> mariadb-java-client-2.6.1-sources.jar: org/mariadb/jdbc/internal/failover/Listener.java <==
/*
 *
 * MariaDB Client for Java
 *
 * Copyright (c) 2012-2014 Monty Program Ab.
 * Copyright (c) 2015-2020 MariaDB Corporation Ab.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this library; if not, write to Monty Program Ab info@montyprogram.com.
 *
 * This particular MariaDB Client for Java file is work
 * derived from a Drizzle-JDBC. Drizzle-JDBC file which is covered by subject to
 * the following copyright and notice provisions:
 *
 * Copyright (c) 2009-2011, Marcus Eriksson
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice, this
 * list of conditions and the following disclaimer in the documentation and/or
 * other materials provided with the distribution.
 *
 * Neither the name of the driver nor the names of its contributors may not be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS  AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
 * OF SUCH DAMAGE.
 *
 */

package org.mariadb.jdbc.internal.failover;

import java.lang.reflect.Method;
import java.net.SocketException;
import java.sql.SQLException;
import java.util.Set;
import org.mariadb.jdbc.HostAddress;
import org.mariadb.jdbc.MariaDbConnection;
import org.mariadb.jdbc.MariaDbStatement;
import org.mariadb.jdbc.UrlParser;
import org.mariadb.jdbc.internal.failover.tools.SearchFilter;
import org.mariadb.jdbc.internal.protocol.Protocol;
import org.mariadb.jdbc.internal.util.dao.ServerPrepareResult;

public interface Listener {

  FailoverProxy getProxy();

  void setProxy(FailoverProxy proxy);

  void initializeConnection() throws SQLException;

  void preExecute() throws SQLException;

  void preClose();

  void preAbort();

  long getServerThreadId();

  void reconnectFailedConnection(SearchFilter filter) throws SQLException;

  void switchReadOnlyConnection(Boolean readonly) throws SQLException;

  HandleErrorResult primaryFail(Method method, Object[] args, boolean killCmd, boolean wasClosed)
      throws SQLException;

  Object invoke(Method method, Object[] args, Protocol specificProtocol) throws Throwable;

  Object invoke(Method method, Object[] args) throws Throwable;

  HandleErrorResult handleFailover(
      SQLException qe, Method method, Object[] args, Protocol protocol, boolean wasClosed)
      throws Throwable;

  void foundActiveMaster(Protocol protocol) throws SQLException;

  Set<HostAddress> getBlacklistKeys();

  void addToBlacklist(HostAddress hostAddress);

  void removeFromBlacklist(HostAddress hostAddress);

  void syncConnection(Protocol from, Protocol to) throws SQLException;

  UrlParser getUrlParser();

  void throwFailoverMessage(
      HostAddress failHostAddress,
      boolean wasMaster,
      SQLException queryException,
      boolean reconnected)
      throws SQLException;

  boolean isAutoReconnect();

  int getRetriesAllDown();

  boolean isExplicitClosed();

  void reconnect() throws SQLException;

  boolean isReadOnly();

  boolean inTransaction();

  int getMajorServerVersion();

  boolean isMasterConnection();

  boolean isClosed();

  boolean versionGreaterOrEqual(int major, int minor, int patch);

  boolean isServerMariaDb();

  boolean sessionStateAware();

  boolean noBackslashEscapes();

  boolean isValid(int timeout) throws SQLException;

  void prolog(long maxRows, MariaDbConnection connection, MariaDbStatement statement)
      throws SQLException;

  String getCatalog() throws SQLException;

  int getTimeout() throws SocketException;

  Protocol getCurrentProtocol();

  boolean hasHostFail();

  boolean canRetryFailLoop();

  SearchFilter getFilterForFailedHost();

  boolean isMasterConnected();

  boolean setMasterHostFail();

  boolean isMasterHostFail();

  long getLastQueryNanos();

  boolean checkMasterStatus(SearchFilter searchFilter);

  void rePrepareOnSlave(ServerPrepareResult oldServerPrepareResult, boolean mustExecuteOnMaster)
      throws SQLException;

  void reset() throws SQLException;
}
